from .base_b import TestConvertBaseTenToBaseB
from .corner_frame import TestCornerFrame
from .dest_rotate_list import TestRotateList
from .medal_allocation import TestMedalAllocation
from .moving_average import TestMovingAverages
from .num_to_word import TestNumberToWords
from .pi import TestPI
from .print_polynomial import TestPolynomialFunctions
from .recursion_gcd import TestGCDFunction
from .reverse_digits import TestReverseDigits
from .substitute_once import TextSubstitutionTest
from .triangle import TestTriangle
from .uniform import TestStringFunctions
